==> pyscitrivia-0.01.tar.gz: pyscitrivia/data/questions/question_modules/chemistry_history.py <==
#PySciTrivia
#Copyright 2005, Michael Atkinson

#This file is part of PySciTrivia.

#PySciTrivia is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

#PySciTrivia is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with PySciTrivia; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#import modules
import os, sys, pygame, random, math
from pygame.locals import *

sys.path.append('sounds')

#initialize pygame
pygame.init()

path = "data/questions/voice/ch/"
def checksound(sound):
	try:
		soundfile = path + sound
		open(soundfile)
		return pygame.mixer.Sound(soundfile)
	except IOError:
		return 0

qnum_ch = 4

n = qnum_ch+1
question_ch = [0]*n
answer_ch = [0]*n
choice1_ch = [0]*n
choice2_ch = [0]*n
choice3_ch = [0]*n
choice4_ch = [0]*n
sound_ch = [0]*n


question_ch[0] = 'What 2 people performed the gold foil experiment under the direction from Ernest Rutherford, revealing much about structure of the atom?'
choice1_ch[0] = 'Henry Moseley and Niels Bohr'
choice2_ch[0] = 'William Eccles and Oliver Heaviside'
choice3_ch[0] = 'Werner Heisenberg and Albert Einstein'
choice4_ch[0] = 'Hans Geiger and Ernest Marsden'
answer_ch[0] = 4
sound_ch[0] = checksound("ch000.ogg")

question_ch[1] = "Boyle's law was independantly discoverd by who 14 years after Robert Boyle had originally done so?"
choice1_ch[1] = 'Edme Mariotte'
choice2_ch[1] = 'Robert Hooke'
choice3_ch[1] = 'Charles-Augustin de Coulomb'
choice4_ch[1] = 'John Dalton'
answer_ch[1] = 1
sound_ch[1] = checksound("ch001.ogg")

question_ch[2] = 'What chemist helped William Ramsay discover and work with many of the noble gases?'
choice1_ch[2] = 'Otto Wallach'
choice2_ch[2] = 'Morris Travers'
choice3_ch[2] = 'Eduard Buchner'
choice4_ch[2] = 'Emil Abderhalden'
answer_ch[2] = 2
sound_ch[2] = checksound("ch002.ogg")

question_ch[3] = 'What famous chemist won a Nobel prize for his work on describing chemical bonds as well as a Nobel Peace Prize advocating against above ground nuclear testing?'
choice1_ch[3] = 'Paul Dirac'
choice2_ch[3] = 'Eugene Wigner'
choice3_ch[3] = 'Linus Pauling'
choice4_ch[3] = u'Le\u00F3 Szil\u00E1rd'
answer_ch[3] =  3
sound_ch[3] = checksound("ch003.ogg")

question_ch[4] = 'Who won a Nobel Prize in physics for research of radiation as well as a Nobel Prize in chemistry for discovering 2 radioactive elements?'
choice1_ch[4] = 'Otto Hahn'
choice2_ch[4] = 'Marie Curie'
choice3_ch[4] = 'Alfred Stock'
choice4_ch[4] = 'Lise Meitner'
answer_ch[4] = 2
sound_ch[4] = checksound("ch004.ogg")

==> pyscitrivia-0.02.tar.gz: pyscitrivia/data/questions/question_modules/chemistry_history.py <==
#!/usr/local/bin/python
#coding: latin-1


#PySciTrivia
#Copyright (C) 2005, 2006 Michael Atkinson

#This file is part of PySciTrivia.

#PySciTrivia is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

#PySciTrivia is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with PySciTrivia; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#import modules
import os, sys, pygame, random, math
from pygame.locals import *

sys.path.append('sounds')

#initialize pygame
pygame.init()

path = "data/questions/voice/ch/"
def checksound(sound):
	try:
		soundfile = path + sound
		open(soundfile)
		return pygame.mixer.Sound(soundfile)
	except IOError:
		return 0

qnum_ch = 9

n = qnum_ch+1
question_ch = [0]*n
answer_ch = [0]*n
choice1_ch = [0]*n
choice2_ch = [0]*n
choice3_ch = [0]*n
choice4_ch = [0]*n
sound_ch = [0]*n


question_ch[0] = 'What 2 people performed the gold foil experiment under the direction from Ernest Rutherford, revealing much about structure of the atom?'
choice1_ch[0] = 'Henry Moseley and Niels Bohr'
choice2_ch[0] = 'William Eccles and Oliver Heaviside'
choice3_ch[0] = 'Werner Heisenberg and Albert Einstein'
choice4_ch[0] = 'Hans Geiger and Ernest Marsden'
answer_ch[0] = 4
sound_ch[0] = checksound("ch000.ogg")

question_ch[1] = "Boyle's law was independantly discoverd by who 14 years after Robert Boyle had originally done so?"
choice1_ch[1] = 'Edme Mariotte'
choice2_ch[1] = 'Robert Hooke'
choice3_ch[1] = 'Charles-Augustin de Coulomb'
choice4_ch[1] = 'John Dalton'
answer_ch[1] = 1
sound_ch[1] = checksound("ch001.ogg")

question_ch[2] = 'What chemist helped William Ramsay discover and work with many of the noble gases?'
choice1_ch[2] = 'Otto Wallach'
choice2_ch[2] = 'Morris Travers'
choice3_ch[2] = 'Eduard Buchner'
choice4_ch[2] = 'Emil Abderhalden'
answer_ch[2] = 2
sound_ch[2] = checksound("ch002.ogg")

question_ch[3] = 'What famous chemist won a Nobel prize for his work on describing chemical bonds as well as a Nobel Peace Prize advocating against above ground nuclear testing?'
choice1_ch[3] = 'Paul Dirac'
choice2_ch[3] = 'Eugene Wigner'
choice3_ch[3] = 'Linus Pauling'
choice4_ch[3] = u'Le\u00F3 Szil\u00E1rd'
answer_ch[3] =  3
sound_ch[3] = checksound("ch003.ogg")

question_ch[4] = 'Who won a Nobel Prize in physics for research of radiation as well as a Nobel Prize in chemistry for discovering 2 radioactive elements?'
choice1_ch[4] = 'Otto Hahn'
choice2_ch[4] = 'Marie Curie'
choice3_ch[4] = 'Alfred Stock'
choice4_ch[4] = 'Lise Meitner'
answer_ch[4] = 2
sound_ch[4] = checksound("ch004.ogg")

question_ch[5] = 'Although others were working on a similar tool at the time, who created the first periodic table taking into account space for elements that had not been discovered at the time?'
choice1_ch[5] = 'John Dalton'
choice2_ch[5] = 'Henry Cavendish'
choice3_ch[5] = 'Anders Celsius'
choice4_ch[5] = 'Dmitri Mendeleev'
answer_ch[5] = 4
sound_ch[5] = checksound("ch005.ogg")

question_ch[6] = 'Wilhelm Conrad Rntgen is credited for having discovered what?'
choice1_ch[6] = 'neutrons'
choice2_ch[6] = 'Radon'
choice3_ch[6] = 'x-rays'
choice4_ch[6] = 'Cadmium'
answer_ch[6] = 3
sound_ch[6] = checksound("ch006.ogg")

question_ch[7] = 'Gallium was discovered by?'
choice1_ch[7] = 'Lecoq de Boisbaudrain'
choice2_ch[7] = 'Marguerite Perey'
choice3_ch[7] = 'Joseph Black'
choice4_ch[7] = 'Humphrey Davy'
answer_ch[7] = 1
sound_ch[7] = checksound("ch007.ogg")

question_ch[8] = 'The barometer was invented in what year?'
choice1_ch[8] = '1345'
choice2_ch[8] = '1643'
choice3_ch[8] = '1601'
choice4_ch[8] = '1755'
answer_ch[8] = 2
sound_ch[8] = checksound("ch008.ogg")

question_ch[9] = 'The voltaic pile, a kind of battery, was developed in what year by Alessandro Volta?'
choice1_ch[9] = '1600'
choice2_ch[9] = '1700'
choice3_ch[9] = '1800'
choice4_ch[9] = '1750'
answer_ch[9] = 3
sound_ch[9] = checksound("ch009.ogg")
